@@ -1,9 +1,8 @@
 package Template::Extract::Run;
-$Template::Extract::Run::VERSION = '0.41';
-
-use 5.006;
+$Template::Extract::Run::VERSION = '0.50';
 use strict;
 use warnings;
+use 5.006;
 
 our ($DEBUG);
 my ( %loop, $cur_loop, $data );
@@ -18,6 +17,7 @@ sub run {
     my ( $self, $regex, $document, $ext_data ) = @_;
 
     $self->_init($ext_data);
+    ## no critic
 
     defined($document) or return undef;
     defined($regex)    or return undef;
@@ -52,7 +52,10 @@ sub _leave_loop {
     my ( $obj, $key, $vars ) = @_;
 
     ref($obj) eq 'HASH' or return;
-    my $old = $obj->{$key} if exists $obj->{$key};
+    my $old;
+    if (exists $obj->{$key}) {
+        $old = $obj->{$key};
+    }
     ref($old) eq 'ARRAY' or return;
 
     print "Validate: [$old $key @$vars]\n" if $DEBUG;
@@ -139,10 +142,18 @@ sub _ext {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Template::Extract::Run - Apply compiled regular expressions on documents
 
+=head1 VERSION
+
+version 0.50
+
 =head1 SYNOPSIS
 
     use Template::Extract::Run;
@@ -214,4 +225,102 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Template-Extract>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Template-Extract>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Template-Extract>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/T/Template-Extract>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Template-Extract>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Template::Extract>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-template-extract at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Template-Extract>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/template-extract>
+
+  git clone git://github.com/shlomif/template-extract.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/template-extract/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2003 by Audrey Tang.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
